@@ -24,7 +24,7 @@
 
 extern uint64_t ZobristKeys[32][SQUARE_NB];
 extern uint64_t ZobristEnpassKeys[FILE_NB];
-extern uint64_t ZobristCastleKeys[0x10];
+extern uint64_t ZobristCastleKeys[SQUARE_NB];
 extern uint64_t ZobristTurnKey;
 
 uint64_t rand64();
